@@ -23,6 +23,7 @@
 
 #include "tracker-decorator.h"
 #include "tracker-priority-queue.h"
+#include "tracker-decorator-private.h"
 
 #define QUERY_BATCH_SIZE 100
 #define DEFAULT_BATCH_SIZE 200
@@ -1281,7 +1282,7 @@ tracker_decorator_started (TrackerMiner *miner)
 	priv = decorator->priv;
 
 	g_timer_start (priv->timer);
-	decorator_cache_next_items (decorator);
+	decorator_rebuild_cache (decorator);
 }
 
 static void
@@ -1758,3 +1759,9 @@ tracker_decorator_info_get_sparql (TrackerDecoratorInfo *info)
 
 	return g_task_get_task_data (info->task);
 }
+
+void
+_tracker_decorator_invalidate_cache (TrackerDecorator *decorator)
+{
+	decorator_rebuild_cache (decorator);
+}
