@@ -759,7 +759,8 @@ open_file (const gchar *filename, FILE *file)
 	infile = gsf_infile_msole_new (input, &error);
 
 	if (error) {
-		g_warning ("Failed to open file '%s': %s", filename, error->message);
+		if (error->domain != gsf_input_error_id ())
+			g_warning ("Failed to open file '%s': %s", filename, error->message);
 		g_error_free (error);
 	}
 
@@ -1372,7 +1373,6 @@ xls_get_extended_record_string (GsfInput  *stream,
 		/* Go to next chunk */
 		i++;
 	}
-	g_free(buffer);
 }
 
 /**
